@@ -18,6 +18,8 @@
 #'
 #' @param Ps TRUE if input is p-value, FALSE if input is Z-scores. The default is FALSE.
 #'
+#' @param prune if it is TRUE, do pruing before the test using pruneSNP function. 
+#'
 #' @return A vector object, MTSPUsSet test P values and MTaSPUsSet P value.
 #'
 #' @author Il-Youp Kwak and Wei Pan
@@ -25,14 +27,14 @@
 #' @references
 #'
 #' Il-Youp Kwak, Wei Pan (2016)
-#'Gene- and pathway-based association tests for multiple
-#'      traits with GWAS summary statistics
+#' Gene- and pathway-based association tests for multiple
+#'      traits with GWAS summary statistics, Bioinformatics, doi:10.1093/bioinformatics/btw577
 #'
 #' @examples
 #'
 #' data(SAMD11)
 #' attach(SAMD11)
-#' ## example analysis using aSPUM test.
+#' ## example analysis using MTaSPUsSet test.
 #' (outFZ <- MTaSPUsSet(ZsF, corSNP=corSNPF, corPhe = corPheF,
 #'       pow=c(1,2,4,8),  pow2 = c(1,2,4,8), n.perm=10, Ps=FALSE))
 #'
@@ -41,7 +43,35 @@
 
 
 MTaSPUsSet <- function(Zs, corSNP, corPhe, pow=c(1,2,4,8),
-                       pow2 = c(1,2,4,8), n.perm=5000, Ps = FALSE) {
+                       pow2 = c(1,2,4,8), n.perm=5000, Ps = FALSE, prune = TRUE) {
+
+    if( dim(corSNP)[1] != dim(corSNP)[2] ){
+        stop(" corSNP should be correlation matrix with same number of rows and columns. ")
+    }
+
+    if( dim(corPhe)[1] != dim(corPhe)[2] ){
+        stop(" corSNP should be correlation matrix with same number of rows and columns. ")
+    }
+
+    if( dim(Zs)[1] != ncol(corSNP) ) {
+        stop(" The number of rows (SNPs) do not match with correlation matrix among SNPs (corSNP) ")
+    }
+
+    if( dim(Zs)[1] != ncol(corSNP) ) {
+        stop(" The number of columns (traits) do not match with correlation matrix among traits (corPhe) ")
+    }
+
+    if(prune== TRUE) {
+        pr <- pruneSNP(corSNP)
+        if( length(pr$to.erase) > 0 ) {
+            Zs <- as.matrix(Zs[-pr$to.erase,])
+            corSNP <- corSNP[-pr$to.erase, -pr$to.erase]
+        }
+    }
+    
+    if( dim(Zs)[1] <= 1 ) {
+        stop("less than 1 SNP.")
+    }
 
     nsnp <- dim(Zs)[1]
     nphe <- dim(Zs)[2]
