@@ -14,6 +14,8 @@
 #'
 #' @param Ps TRUE if input is p-value, FALSE if input is Z-scores. The default is FALSE.
 #'
+#' @param prune if it is TRUE, do pruing before the test using pruneSNP function. 
+#'
 #' @return A list object, Ts : test statistics for the SPU tests (in the order of the specified pow) and finally for the aSPU test.
 #'         pvs : p-values for the SPUs and aSPUs tests.
 #'
@@ -23,7 +25,7 @@
 #'
 #' Il-Youp Kwak, Wei Pan (2015)
 #' Adaptive Gene- and Pathway-Trait Association Testing with GWAS Summary Statistics,
-#' Bioinformatics, doi: 10.1093/bioinformatics/btv719
+#' Bioinformatics, 32(8), 1178-1184.
 #'
 #' @examples
 #'
@@ -37,6 +39,7 @@
 #' ## Take subsets
 #' newP <- kegg9$nP[snps] ;
 #' ldsub <- kegg9$ldmatrix[snps, snps];
+#'
 #' ## Get p-value for gene SOAT1. Read vignette for details.
 #' out <- aSPUs(newP, corSNP=ldsub , pow=c(1:8, Inf), n.perm=100, Ps=TRUE)
 #'
@@ -54,8 +57,25 @@
 #'
 #' @seealso \code{\link{aSPUw}} \code{\link{aSPU}} \code{\link{aSPUsPath}}
 
-aSPUs <- function(Zs, corSNP, pow = c(1:8, Inf), n.perm = 1000, Ps = FALSE)
+aSPUs <- function(Zs, corSNP, pow = c(1:8, Inf), n.perm = 1000, Ps = FALSE, prune = TRUE)
 {
+
+    if(prune== TRUE) {
+        pr <- pruneSNP(corSNP)
+        if( length(pr$to.erase) > 0 ) {
+            Zs <- Zs[-pr$to.erase]
+            corSNP <- corSNP[-pr$to.erase, -pr$to.erase]
+        }
+    }
+    
+    if( length(Zs) <= 1 ) {
+        stop("less than 1 SNP.")
+    }
+
+    if ( !( length(Zs) == dim(corSNP)[1] & dim(corSNP)[2] == dim(corSNP)[1] ) ) {
+        stop("dimension do not match. Check dimension of Zs and corSNP.")
+    }
+    
     n <- length(Zs)
     k <- n
     if(Ps == TRUE)
